@@ -1,6 +1,6 @@
 import pytest
 from click.testing import CliRunner
-from sigma.cli.analyze import analyze_group, analyze_attack, analyze_logsource
+from sigma.cli.analyze import analyze_group, analyze_attack, analyze_logsource, analyze_fields
 from sigma.rule import (
     SigmaRule,
     SigmaLogSource,
@@ -10,6 +10,7 @@ from sigma.rule import (
     SigmaLevel,
     SigmaRuleTag,
 )
+from sigma.types import SigmaString
 from sigma.analyze.attack import (
     calculate_attack_scores,
     score_count,
@@ -100,14 +101,14 @@ def test_attack_invalid_rule():
     cli = CliRunner()
     result = cli.invoke(analyze_attack, ["max", "-", "tests/files/sigma_rule_without_condition.yml"])
     assert result.exit_code != 0
-    assert "at least one condition" in result.stdout
+    assert "at least one condition" in result.stderr
 
 
 @pytest.fixture
 def sigma_rules():
     logsource = SigmaLogSource(category="test")
     detections = SigmaDetections(
-        {"test": SigmaDetection([SigmaDetectionItem("field", [], "value")])}, ["test"]
+        {"test": SigmaDetection([SigmaDetectionItem("field", [], [SigmaString("value")])])}, ["test"]
     )
     return [
         SigmaRule(
@@ -207,4 +208,40 @@ def test_logsource_invalid_rule():
     cli = CliRunner()
     result = cli.invoke(analyze_logsource, ["-", "tests/files/sigma_rule_without_condition.yml"])
     assert result.exit_code != 0
-    assert "at least one condition" in result.stdout
\ No newline at end of file
+    assert "at least one condition" in result.stderr
+
+
+def test_fields_help():
+    cli = CliRunner()
+    result = cli.invoke(analyze_fields, ["--help"])
+    assert result.exit_code == 0
+    assert len(result.stdout.split()) > 8
+
+
+def test_fields_extract():
+    cli = CliRunner()
+    result = cli.invoke(analyze_fields, ["-t", "text_query_test", "-", "tests/files/valid"])
+    assert result.exit_code == 0
+    # Should have extracted at least some fields
+    assert len(result.stdout.split()) > 0
+
+
+def test_fields_extract_correlation_rule():
+    cli = CliRunner()
+    result = cli.invoke(analyze_fields, ["-t", "text_query_test", "-", "tests/files/sigma_correlation_rules.yml"])
+    assert result.exit_code == 0
+    assert len(result.stdout.split()) > 0
+
+
+def test_fields_extract_with_pipelines():
+    cli = CliRunner()
+    result = cli.invoke(analyze_fields, ["-t", "text_query_test", "-p", "tests/files/custom_pipeline.yml", "-p", "dummy_test", "-", "tests/files/valid"])
+    assert result.exit_code == 0
+    assert len(result.stdout.split()) > 0
+
+
+def test_fields_invalid_rule():
+    cli = CliRunner()
+    result = cli.invoke(analyze_fields, ["-t", "text_query_test", "-", "tests/files/sigma_rule_without_condition.yml"])
+    assert result.exit_code != 0
+    assert "at least one condition" in result.stderr
